 #include <LPC21xx.H>
//====================================================================
#define SPI_OK 0 // transfer ended No Errors
#define SPI_BUSY 1 // transfer busy
#define SPI_ERROR 2 // SPI error
static unsigned char state; // State of SPI driver
static unsigned char spiBuf[4]; // SPI data buffer
static unsigned char *msg; // pointer to SPI data buffer
static unsigned char count; // nr of bytes send/received 

 static void SPI_Init(void)
{
	VICVectAddr0 = (unsigned int) &SPI_Isr;
	VICVectCntl0 = 0x2A; // Channel0 on Source#10 ... enabled
	VICIntEnable |= 0x400; // 10th bit is the SPI
	IODIR0 |= 0x00000080; // P0.7 defined as SS_DS1722
	IOCLR0 = 0x00000080; // SS_DS1722 = 0
	PINSEL0 |= 0x00001500; // configure SPI0 pins (except SSEL0)
	S0SPCCR = 12; // SCK = 1 MHz, counter > 8 and even
	S0SPCR = 0xA8; // CPHA=1, CPOL=0, master mode, MSB first, interrupt enabled
}
//====================================================================

void SPI_Isr(void) __irq
{
	if ((S0SPSR & 0xF8) == 0x80)
	{
		*msg++ = S0SPDR; // read byte from slave
	if (--count > 0)
		S0SPDR = *msg; // sent next byte
	else
		state = SPI_OK; // transfer completed
	}
	else // SPI error
	{
		*msg = S0SPDR; // dummy read to clear flags
		state = SPI_ERROR;
	}
	S0SPINT = 0x01; // reset interrupt flag
	VICVectAddr = 0; // reset VIC
}
//====================================================================

static void DS1722_Write(unsigned char add, unsigned char val)
{
	spiBuf[0] = add; // DS1722 address
	spiBuf[1] = val;
	msg = spiBuf;
	count = 2; // nr of bytes
	state = SPI_BUSY; // Status of driver
	IOSET0 = 0x00000080; // SS_DS1722 = 1
	S0SPDR = *msg; // sent first byte
	while (state == SPI_BUSY) ; // wait for end of transfer
	IOCLR0 = 0x00000080; // SS_DS1722 = 0
}